@@ -2,15 +2,16 @@ package Data::Libra;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv('0.0.2');
+use version; our $VERSION = qv('0.0.3');
 use Digest::MD5;
 use Carp;
 
 sub _check_range{
+    my $ref = shift;
     Carp::croak('values range must be less than ' . 0xffffffff . '.') 
-      if $_->[1] - $_->[0] > 0xffffffff;
+      if $ref->[1] - $ref->[0] > 0xffffffff;
     Carp::croak('first param of values must be less than second param.') 
-      if $_->[0] > $_->[1];
+      if $ref->[0] > $ref->[1];
 }
 
 
@@ -80,7 +81,7 @@ I<or>
 
 =head1 DESCRIPTION
 
-Data::Libra generate random values from a string. If you scan the same strings, you will get the same values. It works like "Barcode Battler" or "Monster Rancher(Monster Farm)".
+Data::Libra generate random values from a string. If you scan the same string, you will get the same values. It works like "Barcode Battler" or "Monster Rancher(Monster Farm)".
 
 =head2 Methods
 
